import java.io.*;
import java.util.*;

public class network_av_mincost100 {

	final int MAGIC = 100;

	class Edge implements Comparable<Edge> {
		int from, to, cap, flow, cost;
		Edge rev;

		public Edge(int from, int to, int cap, int cost) {
			super();
			this.from = from;
			this.to = to;
			this.cap = cap;
			this.cost = cost;
		}

		@Override
		public int compareTo(Edge o) {
			return Integer.compare(cost, o.cost);
		}
	}

	List<Edge>[] graph;

	void addEdge(int from, int to, int cost, int cap) {
		Edge st = new Edge(from, to, cap, cost), rev = new Edge(to, from, 0, -cost);
		st.rev = rev;
		rev.rev = st;
		graph[from].add(st);
		graph[to].add(rev);
	}

	class Item implements Comparable<Item> {
		int val, id;

		public Item(int val, int id) {
			super();
			this.val = val;
			this.id = id;
		}

		@Override
		public int compareTo(Item o) {
			return Integer.compare(val, o.val);
		}
	}

	public void solve() {
		int n = in.nextInt(), m = in.nextInt();
		int[] xs = new int[n];
		int[] deg = new int[m], pos = new int[m];
		int ptr1 = 0, ptr2 = 0;
		for (int i = 0; i < n + m; i++) {
			int val = in.nextInt();
			if (val == 0) {
				xs[ptr1++] = i;
			} else {
				pos[ptr2] = i;
				deg[ptr2] = val;
				ptr2++;
			}
		}

		int N = 1 + n + m + 1;
		graph = new List[N];
		for (int i = 0; i < N; i++) {
			graph[i] = new ArrayList<>();
		}

		for (int i = 0; i < n; i++) {
			addEdge(0, i + 1, 0, 1);
		}

		for (int i = 0; i < m; i++) {
			addEdge(1 + n + i, N - 1, 0, deg[i]);
		}

		for (int i = 0; i < n; i++) {
			Item[] items = new Item[m];
			for (int j = 0; j < m; j++) {
				int dist = Math.abs(xs[i] - pos[j]);
				dist = Math.min(dist, n + m - dist);
				items[j] = new Item(dist, j);
			}
			Arrays.sort(items);
			for (int j = 0; j < m && j < MAGIC; j++) {
				addEdge(1 + i, 1 + n + items[j].id, items[j].val, 1);
			}
		}

		for (int i = 0; i < N; i++) {
			Collections.sort(graph[i]);
		}

		final int INF = Integer.MAX_VALUE;
		int[] queue = new int[N * N];
		boolean[] inQueue = new boolean[N];
		Edge[] prev = new Edge[N];
		int[] dist = new int[N];

		int cost = 0;

		for (int I = 0; I < n; I++) {
			Arrays.fill(dist, INF);
			dist[0] = 0;

			int head = 0, tail = 0;
			queue[tail++] = 0;
			inQueue[0] = true;

			while (head < tail) {
				int cur = queue[head++];
				inQueue[cur] = false;
				for (int i = 0; i < graph[cur].size(); i++) {
					Edge e = graph[cur].get(i);
					if (e.flow < e.cap && dist[e.to] > dist[cur] + e.cost) {
						dist[e.to] = dist[cur] + e.cost;
						prev[e.to] = e;
						if (!inQueue[e.to]) {
							inQueue[e.to] = true;
							queue[tail++] = e.to;
						}
					}
				}
			}

			int v = N - 1;
			while (v > 0) {
				Edge e = prev[v];
				cost += e.cost;
				e.flow++;
				e.rev.flow--;
				v = e.from;
			}
		}

		out.println(cost);
	}

	FastScanner in;
	PrintWriter out;

	public void run() {
		try {
			in = new FastScanner();
			out = new PrintWriter(System.out);
			int T = in.nextInt();
			while (T-- > 0) {
				solve();
			}
			out.close();
		} catch (Exception e) {
			e.printStackTrace();
			System.exit(1);
		}
	}

	class FastScanner {
		BufferedReader br;
		StringTokenizer st;

		public FastScanner() {
			br = new BufferedReader(new InputStreamReader(System.in));
		}

		public FastScanner(String name) {
			try {
				br = new BufferedReader(new FileReader(name));
			} catch (FileNotFoundException e) {
				e.printStackTrace();
			}
		}

		public String nextToken() {
			while (st == null || !st.hasMoreElements()) {
				try {
					st = new StringTokenizer(br.readLine());
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
			return st.nextToken();
		}

		public int nextInt() {
			return Integer.parseInt(nextToken());
		}

		public long nextLong() {
			return Long.parseLong(nextToken());
		}

		public double nextDouble() {
			return Double.parseDouble(nextToken());
		}
	}

	public static void main(String[] args) {
		new network_av_mincost100().run();
	}
}
